Csr

Struct Csr 

pub struct Csr<Index: Idx, NI, EV> { /* private fields */ }
A Compressed-Sparse-Row data structure to represent sparse graphs.

The data structure is composed of two arrays: offsets and targets. For a graph with node count n and edge count m, offsets has exactly n + 1 and targets exactly m entries.

For a given node u, offsets[u] stores the start index of the neighbor list of u in targets. The degree of u, i.e., the length of the neighbor list is defined by offsets[u + 1] - offsets[u]. The neighbor list of u is defined by the slice &targets[offsets[u]..offsets[u + 1]].