Module dotgraph

Module dotgraph 

Available on crate feature dotgraph only.

Structs

DotGraph
DotGraphInput
DotGraph (the name is based on the file ending .graph) is a textual description of a node labeled graph primarily used as input for subgraph isomorphism libraries. It has been introduced here and is also supported by the subgraph-matching crate.
LabelStats
NeighborLabelFrequencies
NeighborLabelFrequency
NodeLabelIndex