Graph

Trait Graph 

pub trait Graph<NI: Idx> {
    // Required methods
    fn node_count(&self) -> NI;
    fn edge_count(&self) -> NI;
}
A graph is a tuple (N, E), where N is a set of nodes and E a set of edges. Each edge connects exactly two nodes.

Graph is parameterized over the node index type Node which is used to uniquely identify a node. An edge is a tuple of node identifiers.

Required Methods

fn node_count(&self) -> NI

Returns the number of nodes in the graph.

fn edge_count(&self) -> NI

Returns the number of edges in the graph.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<NI: Idx, NV, EV> Graph<NI> for DirectedALGraph<NI, NV, EV>
where NV: Send + Sync, EV: Send + Sync,

Source

impl<NI: Idx, NV, EV> Graph<NI> for UndirectedALGraph<NI, NV, EV>
where NV: Send + Sync, EV: Send + Sync,

Source

impl<NI: Idx, NV, EV> Graph<NI> for DirectedCsrGraph<NI, NV, EV>

Source

impl<NI: Idx, NV, EV> Graph<NI> for UndirectedCsrGraph<NI, NV, EV>