Available on crate feature
dotgraph only.Structs
- DotGraph
- DotGraph
Input - DotGraph (the name is based on the file ending
.graph) is a textual description of a node labeled graph primarily used as input for subgraph isomorphism libraries. It has been introduced here and is also supported by the subgraph-matching crate. - Label
Stats - Neighbor
Label Frequencies - Neighbor
Label Frequency - Node
Label Index